@@ -2,7 +2,7 @@ from enum import Enum
 
 from sqlglot import exp
 from sqlglot.generator import Generator
-from sqlglot.helper import csv, list_get
+from sqlglot.helper import list_get
 from sqlglot.parser import Parser
 from sqlglot.time import format_time
 from sqlglot.tokens import Tokenizer
@@ -77,7 +77,6 @@ class Dialect(metaclass=_Dialect):
     alias_post_tablesample = False
     normalize_functions = "upper"
     null_ordering = "nulls_are_small"
-    wrap_derived_values = True
 
     date_format = "'%Y-%m-%d'"
     dateint_format = "'%Y%m%d'"
@@ -170,7 +169,6 @@ class Dialect(metaclass=_Dialect):
                 "alias_post_tablesample": self.alias_post_tablesample,
                 "normalize_functions": self.normalize_functions,
                 "null_ordering": self.null_ordering,
-                "wrap_derived_values": self.wrap_derived_values,
                 **opts,
             }
         )
@@ -179,11 +177,11 @@ class Dialect(metaclass=_Dialect):
 def rename_func(name):
     def _rename(self, expression):
         args = (
-            self.expressions(expression, flat=True)
+            expression.expressions
             if isinstance(expression, exp.Func) and expression.is_var_len_args
-            else csv(*[self.sql(e) for e in expression.args.values()])
+            else expression.args.values()
         )
-        return f"{name}({args})"
+        return f"{name}({self.format_args(*args)})"
 
     return _rename
 
@@ -191,15 +189,11 @@ def rename_func(name):
 def approx_count_distinct_sql(self, expression):
     if expression.args.get("accuracy"):
         self.unsupported("APPROX_COUNT_DISTINCT does not support accuracy")
-    return f"APPROX_COUNT_DISTINCT({self.sql(expression, 'this')})"
+    return f"APPROX_COUNT_DISTINCT({self.format_args(expression.this)})"
 
 
 def if_sql(self, expression):
-    expressions = csv(
-        self.sql(expression, "this"),
-        self.sql(expression, "true"),
-        self.sql(expression, "false"),
-    )
+    expressions = self.format_args(expression.this, expression.args.get("true"), expression.args.get("false"))
     return f"IF({expressions})"
 
 
@@ -271,6 +265,21 @@ def struct_extract_sql(self, expression):
     return f"{this}.{struct_key}"
 
 
+def var_map_sql(self, expression):
+    keys = expression.args["keys"]
+    values = expression.args["values"]
+
+    if not isinstance(keys, exp.Array) or not isinstance(values, exp.Array):
+        self.unsupported("Cannot convert array columns into map.")
+        return f"MAP({self.format_args(keys, values)})"
+
+    args = []
+    for key, value in zip(keys.expressions, values.expressions):
+        args.append(self.sql(key))
+        args.append(self.sql(value))
+    return f"MAP({self.format_args(*args)})"
+
+
 def format_time_lambda(exp_class, dialect, default=None):
     """Helper used for time expressions.
 
